@@ -1,8 +1,10 @@
 mod add;
 mod clean;
 mod edit;
+mod environment_variables;
 mod group;
 mod kill;
+mod log;
 mod parallel_tasks;
 mod pause;
 mod remove;
